#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['pycraigslist', 'pycraigslist.query']

package_data = \
{'': ['*']}

install_requires = \
['httpx>=0.18.0',
 'beautifulsoup4>=4.9.0',
 'tenacity>=7.0.0',
 'cchardet>=2.1.0',
 'lxml>=4.6.0']

setup(name='pycraigslist',
      version='0.6.3',
      description='pycraigslist API library',
      author='Ira Horecka',
      author_email='ira89@icloud.com',
      url='https://github.com/irahorecka/pycraigslist',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3.6',
     )
